@@ -19,7 +19,7 @@ def FC_AConnect(output_size,Wstd=0,Bstd=0,isBin="no",pool=None,Slice=1,d_type=tf
 	class FC_AConnect(tf.keras.layers.Layer): 
 		def __init__(self,output_size,Wstd=0,Bstd=0,isBin="no",pool=None,Slice=1,d_type=tf.dtypes.float32,weights_regularizer=None,bias_regularizer=None
 		,**kwargs): #__init__ method is the first method used for an object in python to initialize the ...
-			super(AConnect, self).__init__()						 		#...object attributes
+			super(FC_AConnect, self).__init__()						 		#...object attributes
 			self.output_size = output_size							 		#output_size is the number of neurons of the layer
 			self.Wstd = Wstd										 		#Wstd standard deviation of the weights(number between 0-1. By default is 0)
 			self.Bstd = Bstd										 		#Bstd standard deviation of the bias(number between 0-1. By default is 0)       
@@ -64,7 +64,7 @@ def FC_AConnect(output_size,Wstd=0,Bstd=0,isBin="no",pool=None,Slice=1,d_type=tf
 			else:
 				self.Werr = tf.constant(1,dtype=self.d_type) #We need to define the number 1 as a float32.
 				self.Berr = tf.constant(1,dtype=self.d_type)
-			super(AConnect, self).build(input_shape)
+			super(FC_AConnect, self).build(input_shape)
 			
 		def call(self, X, training=None): #With call we can define all the operations that the layer do in the forward propagation.
 			self.X = tf.cast(X, dtype=self.d_type)
